@@ -2,10 +2,6 @@
 Rejected is a Python RabbitMQ Consumer Framework and Controller Daemon
 
 """
-__author__ = 'Gavin M. Roy <gavinmroy@gmail.com>'
-__since__ = '2009-09-10'
-__version__ = '3.13.3'
-
 import logging
 from logging import NullHandler
 
@@ -18,13 +14,18 @@ from rejected.consumer import SmartConsumer
 from rejected.consumer import SmartPublishingConsumer
 from rejected.consumer import ConsumerException
 from rejected.consumer import MessageException
+from rejected.consumer import ProcessingException
+
+__author__ = 'Gavin M. Roy <gavinmroy@gmail.com>'
+__since__ = '2009-09-10'
+__version__ = '3.19.5'
 
 __all__ = [
-    '__version__',
     'Consumer',
     'PublishingConsumer',
     'SmartConsumer',
     'SmartPublishingConsumer',
     'ConsumerException',
-    'MessageException'
+    'MessageException',
+    'ProcessingException'
 ]
